const MAX_SCREEN_SIZE = 256;

export class Screen {
  constructor(entity) {
    this.entity = entity;
    this.painted = false;
  }

  paint(payload) {
    return new Promise((resolve, reject) => {
      if (this.painted) reject("Painted");
      this.setCursor(0);
      if (this.entity.getComponent("health").current < MAX_SCREEN_SIZE) {
        const pixelIdx = this.entity.getComponent("health").current;
        const pixel = payload[pixelIdx];
        this.paintPixel(pixelIdx, pixel);
      }
      this.painted = true;
      resolve(true);
    });
  }

  paintPixel(position, colors) {
    this.setCursor(position);
    this.setBrush(colors);
  }

  setCursor(x) {
    const health = this.entity.getComponent("health");
    this._triggerEvent(`set_pixel_pos(${x})`);
    health.resetToMaxValue();
  }

  setBrush(colors) {
    const [ r, g, b ] = colors;

    this._triggerEvent(`set_brush_r(${r})`);
    this._triggerEvent(`set_brush_g(${g})`);
    this._triggerEvent(`set_brush_b(${b})`);
    this._triggerEvent(`paint`);
  }

  _triggerEvent(event) {
    return this.entity.triggerEvent(event);
  }
}